# teritorio: ISO codes for countries and currencies

[![build][build_badge]][build_url]
[![lint][lint_badge]][lint_url]
[![tests][tests_badge]][tests_url]
[![license][licence_badge]][licence_url]
[![codecov][codecov_badge]][codecov_url]
[![readthedocs][readthedocs_badge]][readthedocs_url]
[![pypi][pypi_badge]][pypi_url]
[![downloads][pepy_badge]][pepy_url]
[![build automation: yam][yam_badge]][yam_url]
[![Lint: ruff][ruff_badge]][ruff_url]

`teritorio` two iterable singletons that `Countries` and `Currencies`,
that contain all the relevant ISO information about countries and
currencies, respectively.

## Versioning

The project project adheres to [Calendar Versioning](https://calver.org). The reason is that the data are
dominated by political decisions, making semantic versioning largely irrelevant.

## Links

- [Documentation]
- [Changelog]

[build_badge]: https://github.com/spapanik/teritorio/actions/workflows/build.yml/badge.svg
[build_url]: https://github.com/spapanik/teritorio/actions/workflows/build.yml
[lint_badge]: https://github.com/spapanik/teritorio/actions/workflows/lint.yml/badge.svg
[lint_url]: https://github.com/spapanik/teritorio/actions/workflows/lint.yml
[tests_badge]: https://github.com/spapanik/teritorio/actions/workflows/tests.yml/badge.svg
[tests_url]: https://github.com/spapanik/teritorio/actions/workflows/tests.yml
[licence_badge]: https://img.shields.io/pypi/l/teritorio
[licence_url]: https://teritorio.readthedocs.io/en/stable/LICENSE/
[codecov_badge]: https://codecov.io/github/spapanik/teritorio/graph/badge.svg?token=Q20F84BW72
[codecov_url]: https://codecov.io/github/spapanik/teritorio
[readthedocs_badge]: https://readthedocs.org/projects/teritorio/badge/?version=latest
[readthedocs_url]: https://teritorio.readthedocs.io/en/latest/
[pypi_badge]: https://img.shields.io/pypi/v/teritorio
[pypi_url]: https://pypi.org/project/teritorio
[pepy_badge]: https://pepy.tech/badge/teritorio
[pepy_url]: https://pepy.tech/project/teritorio
[yam_badge]: https://img.shields.io/badge/build%20automation-yamk-success
[yam_url]: https://github.com/spapanik/yamk
[ruff_badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json
[ruff_url]: https://github.com/charliermarsh/ruff
[Documentation]: https://teritorio.readthedocs.io/en/stable/
[Changelog]: https://teritorio.readthedocs.io/en/stable/CHANGELOG/
[Calendar Versioning]: https://calver.org
